/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gdk;
import org.gnu.glib.Boxed;
import org.gnu.glib.Handle;
public class Pango extends Boxed 
{
    /****************************************
     * BEGINNING OF GENERATED CODE
     ****************************************/
    native static final protected Handle gdk_pango_context_get ();
    native static final protected void gdk_pango_context_set_colormap (Handle context, Handle colormap);
    /****************************************
     * END OF GENERATED CODE
     ****************************************/
}

